# eis-publicapi
The Emil Public API description

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0
- Package version: 1.22.1
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://www.emil.de](https://www.emil.de)

## Requirements.

Python >=3.6

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install eis.publicapi
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import eis.publicapi
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import eis.publicapi
```

## Getting Started

The environment variables must be set in order to properly use this SDK.

```shell 
export EMIL_USERNAME=XXXXXXX
export EMIL_PASSWORD=XXXXXXX
```

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
import time
import eis.publicapi
from pprint import pprint
from eis.publicapi.api import address_completions_validations_api
from eis.publicapi.model.address_completion_response_class import AddressCompletionResponseClass
from eis.publicapi.model.validate_address_response_class import ValidateAddressResponseClass
# Defining the host is optional and defaults to https://apiv2.emil.de
# See configuration.py for a list of all supported configuration parameters.
configuration = eis.publicapi.Configuration(
    host = "https://apiv2.emil.de"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Bearer is automatically handled with exported environment variables. However, you
# can manuallay configure Bearer authorization (JWT): bearer
configuration = eis.publicapi.Configuration(
    access_token = 'YOUR_BEARER_TOKEN'
)

# After manual token becomes invalid, the SDK will default to re-login automatically
# with environment variable credentials.


# Enter a context with an instance of the API client
with eis.publicapi.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = address_completions_validations_api.AddressCompletionsValidationsApi(api_client)
    partial_address = "29 Acker" # str | Partial address for completion
    authorization = "Authorization_example" # str | Bearer Token (optional)
    country = "Germany" # str | This property can be used to filter addresses by country (optional)
    limit = 5 # float | The number of results to fetch (optional)

    try:
        # Retrieve the address
        api_response = api_instance.list_address_completions(partial_address, authorization=authorization, country=country, limit=limit)
        pprint(api_response)
    except eis.publicapi.ApiException as e:
        print("Exception when calling AddressCompletionsValidationsApi->list_address_completions: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://apiv2.emil.de*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AddressCompletionsValidationsApi* | [**list_address_completions**](docs/AddressCompletionsValidationsApi.md#list_address_completions) | **GET** /publicapi/v1/addresses/completions | Retrieve the address
*AddressCompletionsValidationsApi* | [**validate_address**](docs/AddressCompletionsValidationsApi.md#validate_address) | **GET** /publicapi/v1/addresses/validation | Retrieve the Address validation
*DocumentsApi* | [**create_temporary_document**](docs/DocumentsApi.md#create_temporary_document) | **POST** /publicapi/v1/documents | Create the temporary document
*DocumentsApi* | [**delete_documents**](docs/DocumentsApi.md#delete_documents) | **DELETE** /publicapi/v1/documents/{code}/lead/{leadCode} | Delete a document
*DocumentsApi* | [**download_document**](docs/DocumentsApi.md#download_document) | **GET** /publicapi/v1/documents/download/{code} | Download a document
*DocumentsApi* | [**download_product_document_url**](docs/DocumentsApi.md#download_product_document_url) | **GET** /publicapi/v1/documents/product/{productCode}/{code}/download-url | Get pre-signed url for downloading product document
*DocumentsApi* | [**list_documents**](docs/DocumentsApi.md#list_documents) | **GET** /publicapi/v1/documents | List documents
*DocumentsApi* | [**list_product_documents**](docs/DocumentsApi.md#list_product_documents) | **GET** /publicapi/v1/documents/{productCode} | List product documents
*DocumentsApi* | [**pre_signed_post**](docs/DocumentsApi.md#pre_signed_post) | **POST** /publicapi/v1/documents/pre-signed-post | Upload documents using pre-signed URL
*LeadsApi* | [**create_lead**](docs/LeadsApi.md#create_lead) | **POST** /publicapi/v1/leads | Create the lead
*LeadsApi* | [**create_lead_async**](docs/LeadsApi.md#create_lead_async) | **POST** /publicapi/v1/leads-async | Create the lead asynchronously
*LeadsApi* | [**create_lead_sync**](docs/LeadsApi.md#create_lead_sync) | **POST** /publicapi/v1/leads-sync | Create the lead synchronously
*LeadsApi* | [**get_lead**](docs/LeadsApi.md#get_lead) | **GET** /publicapi/v1/leads/{code} | Retrieve the lead
*LeadsApi* | [**initiate_lead**](docs/LeadsApi.md#initiate_lead) | **POST** /publicapi/v1/leads/initiate | Initiate a lead code
*LeadsApi* | [**update_lead**](docs/LeadsApi.md#update_lead) | **PUT** /publicapi/v1/leads/{code} | Update the lead
*LeadsApi* | [**update_lead_sync**](docs/LeadsApi.md#update_lead_sync) | **PUT** /publicapi/v1/leads-sync/{code} | Update the lead
*NotificationsApi* | [**complete_email_verification**](docs/NotificationsApi.md#complete_email_verification) | **POST** /publicapi/v1/email-verification/complete | Complete Email Verification.
*NotificationsApi* | [**initiate_email_verification**](docs/NotificationsApi.md#initiate_email_verification) | **POST** /publicapi/v1/email-verification/initiate | Initiate Email Verification.
*NotificationsApi* | [**send_notification**](docs/NotificationsApi.md#send_notification) | **POST** /publicapi/v1/emails/send | Send an email.
*PaymentsSetupApi* | [**complete_payment_setup**](docs/PaymentsSetupApi.md#complete_payment_setup) | **POST** /publicapi/v1/payment-setup/complete | Complete a payment setup
*PaymentsSetupApi* | [**get_public_psp_config**](docs/PaymentsSetupApi.md#get_public_psp_config) | **GET** /publicapi/v1/payment-setup/get-psp-config | Get public key and psp
*PaymentsSetupApi* | [**initiate_payment_setup**](docs/PaymentsSetupApi.md#initiate_payment_setup) | **POST** /publicapi/v1/payment-setup/initiate | Initiate a payment setup
*ProductsApi* | [**calculate_product_fields**](docs/ProductsApi.md#calculate_product_fields) | **POST** /publicapi/v1/products/{product_code}/calculate-product-fields | Create the product fields
*ProductsApi* | [**create_estimated_invoice**](docs/ProductsApi.md#create_estimated_invoice) | **POST** /publicapi/v1/products/{product_code}/product-invoice | Create the invoice product
*ProductsApi* | [**custom_application**](docs/ProductsApi.md#custom_application) | **POST** /publicapi/v1/products/{product_code}/custom-application | Create the custom application
*ProductsApi* | [**get_insured_object_types**](docs/ProductsApi.md#get_insured_object_types) | **GET** /publicapi/v1/products/{product_code}/insured-object-types | List insured object types
*ProductsApi* | [**get_insured_objects**](docs/ProductsApi.md#get_insured_objects) | **GET** /publicapi/v1/products/{product_code}/insured-objects | List insured objects
*ProductsApi* | [**get_product_custom_css**](docs/ProductsApi.md#get_product_custom_css) | **GET** /publicapi/v1/products/{product_code}/custom-css | Generate a custom CSS
*ProductsApi* | [**get_product_factors**](docs/ProductsApi.md#get_product_factors) | **GET** /publicapi/v1/products/{product_code}/product-factors | List product factors
*ProductsApi* | [**list_products**](docs/ProductsApi.md#list_products) | **GET** /publicapi/v1/products | List products
*DefaultApi* | [**check**](docs/DefaultApi.md#check) | **GET** /publicapi/health | 


## Documentation For Models

 - [AddressCompletionItemClass](docs/AddressCompletionItemClass.md)
 - [AddressCompletionResponseClass](docs/AddressCompletionResponseClass.md)
 - [AddressFieldScoreClass](docs/AddressFieldScoreClass.md)
 - [CalculateProductFieldsRequestDto](docs/CalculateProductFieldsRequestDto.md)
 - [CalculateProductFieldsResponseClass](docs/CalculateProductFieldsResponseClass.md)
 - [CompleteBraintreePaymentSetupRequestDto](docs/CompleteBraintreePaymentSetupRequestDto.md)
 - [CompleteEmailVerificationDto](docs/CompleteEmailVerificationDto.md)
 - [CompleteEmailVerificationResponseClass](docs/CompleteEmailVerificationResponseClass.md)
 - [CompletePaymentSetupRequestDto](docs/CompletePaymentSetupRequestDto.md)
 - [CompletePaymentSetupResponseClass](docs/CompletePaymentSetupResponseClass.md)
 - [CompleteStripePaymentSetupRequestDto](docs/CompleteStripePaymentSetupRequestDto.md)
 - [CreateAccountRequestDto](docs/CreateAccountRequestDto.md)
 - [CreateBankAccountRequestDto](docs/CreateBankAccountRequestDto.md)
 - [CreateCustomApplicationRequestDto](docs/CreateCustomApplicationRequestDto.md)
 - [CreateCustomApplicationResponseClass](docs/CreateCustomApplicationResponseClass.md)
 - [CreateDocumentRequestDto](docs/CreateDocumentRequestDto.md)
 - [CreateEstimatedInvoiceRequestDto](docs/CreateEstimatedInvoiceRequestDto.md)
 - [CreateEstimatedInvoiceResponseClass](docs/CreateEstimatedInvoiceResponseClass.md)
 - [CreateLeadAsyncResponseClass](docs/CreateLeadAsyncResponseClass.md)
 - [CreateLeadRequestDto](docs/CreateLeadRequestDto.md)
 - [CreateLeadResponseClass](docs/CreateLeadResponseClass.md)
 - [CreatePaymentMethodRequestDto](docs/CreatePaymentMethodRequestDto.md)
 - [CreatePresignedPostRequestDto](docs/CreatePresignedPostRequestDto.md)
 - [CreatePresignedPostResponseClass](docs/CreatePresignedPostResponseClass.md)
 - [DocumentClass](docs/DocumentClass.md)
 - [GetCustomCssResponseClass](docs/GetCustomCssResponseClass.md)
 - [GetLeadResponseClass](docs/GetLeadResponseClass.md)
 - [GetProductDocumentDownloadUrlResponseClass](docs/GetProductDocumentDownloadUrlResponseClass.md)
 - [GetPublicPspSettingsResponseClass](docs/GetPublicPspSettingsResponseClass.md)
 - [InitiateBraintreePaymentSetupRequestDto](docs/InitiateBraintreePaymentSetupRequestDto.md)
 - [InitiateBraintreePaymentSetupResponseClass](docs/InitiateBraintreePaymentSetupResponseClass.md)
 - [InitiateEmailVerificationDto](docs/InitiateEmailVerificationDto.md)
 - [InitiateEmailVerificationResponseClass](docs/InitiateEmailVerificationResponseClass.md)
 - [InitiateLeadResponseClass](docs/InitiateLeadResponseClass.md)
 - [InitiatePaymentSetupRequestDto](docs/InitiatePaymentSetupRequestDto.md)
 - [InitiatePaymentSetupResponseClass](docs/InitiatePaymentSetupResponseClass.md)
 - [InitiateStripePaymentSetupRequestDto](docs/InitiateStripePaymentSetupRequestDto.md)
 - [InitiateStripePaymentSetupResponseClass](docs/InitiateStripePaymentSetupResponseClass.md)
 - [InlineResponse200](docs/InlineResponse200.md)
 - [InlineResponse503](docs/InlineResponse503.md)
 - [InsuredObjectClass](docs/InsuredObjectClass.md)
 - [InsuredObjectTypeClass](docs/InsuredObjectTypeClass.md)
 - [InvoiceClass](docs/InvoiceClass.md)
 - [InvoiceItemClass](docs/InvoiceItemClass.md)
 - [InvoiceStatusClass](docs/InvoiceStatusClass.md)
 - [LeadAccountClass](docs/LeadAccountClass.md)
 - [LeadBankAccountClass](docs/LeadBankAccountClass.md)
 - [LeadClass](docs/LeadClass.md)
 - [LeadPolicyClass](docs/LeadPolicyClass.md)
 - [LeadPolicyObjectClass](docs/LeadPolicyObjectClass.md)
 - [ListDocumentsResponseClass](docs/ListDocumentsResponseClass.md)
 - [ListProductDocumentsResponseClass](docs/ListProductDocumentsResponseClass.md)
 - [ListProductsResponseClass](docs/ListProductsResponseClass.md)
 - [PaymentMethodClass](docs/PaymentMethodClass.md)
 - [PolicyObjectRequestDto](docs/PolicyObjectRequestDto.md)
 - [PolicyObjectResponseClass](docs/PolicyObjectResponseClass.md)
 - [PremiumOverrideDto](docs/PremiumOverrideDto.md)
 - [PremiumOverrideRequestDto](docs/PremiumOverrideRequestDto.md)
 - [ProductClass](docs/ProductClass.md)
 - [ProductDocumentClass](docs/ProductDocumentClass.md)
 - [ProductFactorForVersionClass](docs/ProductFactorForVersionClass.md)
 - [ProductFieldClass](docs/ProductFieldClass.md)
 - [ProductVersionClass](docs/ProductVersionClass.md)
 - [SendNotificationRequestDto](docs/SendNotificationRequestDto.md)
 - [SendNotificationResponseClass](docs/SendNotificationResponseClass.md)
 - [SepaDto](docs/SepaDto.md)
 - [StructuredAddressClass](docs/StructuredAddressClass.md)
 - [SuggestedAddressDetailsClass](docs/SuggestedAddressDetailsClass.md)
 - [UpdateLeadRequestDto](docs/UpdateLeadRequestDto.md)
 - [UpdateLeadResponseClass](docs/UpdateLeadResponseClass.md)
 - [UploadedDocumentDto](docs/UploadedDocumentDto.md)
 - [ValidateAddressResponseClass](docs/ValidateAddressResponseClass.md)


## Documentation For Authorization


## bearer

- **Type**: Bearer authentication (JWT)


## Author

kontakt@emil.de


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in eis.publicapi.apis and eis.publicapi.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from eis.publicapi.api.default_api import DefaultApi`
- `from eis.publicapi.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import eis.publicapi
from eis.publicapi.apis import *
from eis.publicapi.models import *
```

